@@ -182,7 +182,7 @@ class _no_spaces_parser:
                 dt = strptime(datestring, fmt), cls._get_period(fmt)
                 if len(str(dt[0].year)) == 4:
                     return dt
-            except:
+            except Exception:
                 pass
         return None
 
@@ -216,7 +216,7 @@ class _no_spaces_parser:
                     missing = _get_missing_parts(fmt)
                     _check_strict_parsing(missing, settings)
                     return dt
-                except:
+                except Exception:
                     pass
         else:
             if ambiguous_date:
@@ -332,7 +332,7 @@ class _parser:
                     token.index(":")
                     # Is after period? raise ValueError if '.' can't be found:
                     self.tokens[self.tokens.index((token, 0)) + 1][0].index(".")
-                except:
+                except Exception:
                     microsecond = None
 
                 if microsecond:
@@ -342,7 +342,7 @@ class _parser:
                     meridian = MERIDIAN.search(
                         self.filtered_tokens[meridian_index][0]
                     ).group()
-                except:
+                except Exception:
                     meridian = None
 
                 if any([":" in token, meridian, microsecond]):
@@ -514,9 +514,9 @@ class _parser:
 
         # NOTE: If this assert fires, self.now needs to be made offset-aware in a similar
         # way that dateobj is temporarily made offset-aware.
-        assert not (
-            self.now.tzinfo is None and dateobj.tzinfo is not None
-        ), "`self.now` doesn't have `tzinfo`. Review comment in code for details."
+        assert not (self.now.tzinfo is None and dateobj.tzinfo is not None), (
+            "`self.now` doesn't have `tzinfo`. Review comment in code for details."
+        )
 
         # Store the original dateobj values so that upon subsequent parsing everything is not
         # treated as offset-aware if offset awareness is changed.
@@ -563,18 +563,15 @@ class _parser:
             # Convert dateobj to utc time to compare with self.now
             try:
                 tz = tz or get_timezone_from_tz_string(self.settings.TIMEZONE)
-            except pytz.UnknownTimeZoneError:
-                tz = None
+                tz_offset = tz.utcoffset(dateobj)
+            except (pytz.UnknownTimeZoneError, pytz.NonExistentTimeError):
+                tz_offset = timedelta(hours=0)
 
-            if tz:
-                dateobj_time = (dateobj - tz.utcoffset(dateobj)).time()
-            else:
-                dateobj_time = dateobj.time()
             if "past" in self.settings.PREFER_DATES_FROM:
-                if self.now.time() < dateobj_time:
+                if self.now < dateobj - tz_offset:
                     dateobj = dateobj + timedelta(days=-1)
             if "future" in self.settings.PREFER_DATES_FROM:
-                if self.now.time() > dateobj_time:
+                if self.now > dateobj - tz_offset:
                     dateobj = dateobj + timedelta(days=1)
 
         # Reset dateobj to the original value, thus removing any offset awareness that may
@@ -601,10 +598,13 @@ class _parser:
         relative_base_month = (
             relative_base.month if hasattr(relative_base, "month") else relative_base
         )
-        if getattr(self, "_token_month", None) or relative_base_month:
+
+        if getattr(self, "_token_month", None):
             return dateobj
 
-        dateobj = set_correct_month_from_settings(dateobj, self.settings)
+        dateobj = set_correct_month_from_settings(
+            dateobj, self.settings, relative_base_month
+        )
         return dateobj
 
     @classmethod
@@ -616,11 +616,13 @@ class _parser:
         # correction for past, future if applicable
         dateobj = po._correct_for_time_frame(dateobj, tz)
 
+        # correction for preference of month: beginning, current, end
+        # must happen before day so that day is derived from the correct month
+        dateobj = po._correct_for_month(dateobj)
+
         # correction for preference of day: beginning, current, end
         dateobj = po._correct_for_day(dateobj)
 
-        # correction for preference of month: beginning, current, end
-        dateobj = po._correct_for_month(dateobj)
         period = po._get_period()
 
         return dateobj, period
@@ -684,7 +686,7 @@ class _parser:
                                 (component, getattr(do, component)),
                                 ("day", prev_value),
                             ]
-                    except:
+                    except Exception:
                         pass
             else:
                 raise ValueError("Unable to parse: %s" % token)
